==> zio-aws-ssoadmin_3-5.17.267.6-sources.jar: zio/aws/ssoadmin/model/DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.ssoadmin.model.primitives.{PermissionSetArn, InstanceArn}
import scala.jdk.CollectionConverters.*
final case class DetachCustomerManagedPolicyReferenceFromPermissionSetRequest(
    instanceArn: InstanceArn,
    permissionSetArn: PermissionSetArn,
    customerManagedPolicyReference: zio.aws.ssoadmin.model.CustomerManagedPolicyReference
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest = {
    import DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
      .builder()
      .instanceArn(InstanceArn.unwrap(instanceArn): java.lang.String)
      .permissionSetArn(
        PermissionSetArn.unwrap(permissionSetArn): java.lang.String
      )
      .customerManagedPolicyReference(
        customerManagedPolicyReference.buildAwsValue()
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly =
    zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
      .wrap(buildAwsValue())
}
object DetachCustomerManagedPolicyReferenceFromPermissionSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest =
      zio.aws.ssoadmin.model
        .DetachCustomerManagedPolicyReferenceFromPermissionSetRequest(
          instanceArn,
          permissionSetArn,
          customerManagedPolicyReference.asEditable
        )
    def instanceArn: InstanceArn
    def permissionSetArn: PermissionSetArn
    def customerManagedPolicyReference
        : zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly
    def getInstanceArn: ZIO[Any, Nothing, InstanceArn] =
      ZIO.succeed(instanceArn)
    def getPermissionSetArn: ZIO[Any, Nothing, PermissionSetArn] =
      ZIO.succeed(permissionSetArn)
    def getCustomerManagedPolicyReference: ZIO[
      Any,
      Nothing,
      zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly
    ] = ZIO.succeed(customerManagedPolicyReference)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ) extends zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly {
    override val instanceArn: InstanceArn =
      zio.aws.ssoadmin.model.primitives.InstanceArn(impl.instanceArn())
    override val permissionSetArn: PermissionSetArn =
      zio.aws.ssoadmin.model.primitives
        .PermissionSetArn(impl.permissionSetArn())
    override val customerManagedPolicyReference
        : zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly =
      zio.aws.ssoadmin.model.CustomerManagedPolicyReference
        .wrap(impl.customerManagedPolicyReference())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ): zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-6.20.162.2-sources.jar: zio/aws/ssoadmin/model/DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.ssoadmin.model.primitives.{PermissionSetArn, InstanceArn}
import scala.jdk.CollectionConverters.*
final case class DetachCustomerManagedPolicyReferenceFromPermissionSetRequest(
    customerManagedPolicyReference: zio.aws.ssoadmin.model.CustomerManagedPolicyReference,
    instanceArn: InstanceArn,
    permissionSetArn: PermissionSetArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest = {
    import DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
      .builder()
      .customerManagedPolicyReference(
        customerManagedPolicyReference.buildAwsValue()
      )
      .instanceArn(InstanceArn.unwrap(instanceArn): java.lang.String)
      .permissionSetArn(
        PermissionSetArn.unwrap(permissionSetArn): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly =
    zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
      .wrap(buildAwsValue())
}
object DetachCustomerManagedPolicyReferenceFromPermissionSetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest =
      zio.aws.ssoadmin.model
        .DetachCustomerManagedPolicyReferenceFromPermissionSetRequest(
          customerManagedPolicyReference.asEditable,
          instanceArn,
          permissionSetArn
        )
    def customerManagedPolicyReference
        : zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly
    def instanceArn: InstanceArn
    def permissionSetArn: PermissionSetArn
    def getCustomerManagedPolicyReference: ZIO[
      Any,
      Nothing,
      zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly
    ] = ZIO.succeed(customerManagedPolicyReference)
    def getInstanceArn: ZIO[Any, Nothing, InstanceArn] =
      ZIO.succeed(instanceArn)
    def getPermissionSetArn: ZIO[Any, Nothing, PermissionSetArn] =
      ZIO.succeed(permissionSetArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ) extends zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly {
    override val customerManagedPolicyReference
        : zio.aws.ssoadmin.model.CustomerManagedPolicyReference.ReadOnly =
      zio.aws.ssoadmin.model.CustomerManagedPolicyReference
        .wrap(impl.customerManagedPolicyReference())
    override val instanceArn: InstanceArn =
      zio.aws.ssoadmin.model.primitives.InstanceArn(impl.instanceArn())
    override val permissionSetArn: PermissionSetArn =
      zio.aws.ssoadmin.model.primitives
        .PermissionSetArn(impl.permissionSetArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
  ): zio.aws.ssoadmin.model.DetachCustomerManagedPolicyReferenceFromPermissionSetRequest.ReadOnly =
    new Wrapper(impl)
}
